<div class="side-panel border-box">
    <form class="form">
        <h1>Get news updates</h1>
        <input type="text" class="text-field" placeholder="Your email address"
               data-object="textfield" autocomplete="off" data-value="" />
        <div class="buttons">
            <div class="button button-color button-green button-confirm" data-submit="1">Subscribe</div>
            <div class="button button-color button-grey button-cancel">Cancel</div>
        </div>
    </form>
</div>
